@@ -52,7 +52,7 @@ impl<ApiErrorType> RestApiClient<ApiErrorType>
 where
     ApiErrorType: DeserializeOwned + ToString + Clone
 {
-    pub async fn get<ResponseDataType>(self, path: &str) -> CrateResult<ResponseDataType>
+    pub async fn get<ResponseDataType>(&self, path: &str) -> CrateResult<ResponseDataType>
     where 
         ResponseDataType: DeserializeOwned
     {
